NAME = "blue_flie"

ICON = "🦋"

DESCRIPTION = f"{ICON} flying with AI."

VERSION = "4.74.1"

REPO_NAME = "blue-flie"

MARQUEE = "https://www.bitcraze.io/images/documentation/overview/system_overview.jpg"

ALIAS = "@flie"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
